import { sortBy } from "lodash-es";
import { basename, sep as osSpecificPathSeparator } from "path";
import { parseTorrentFromFilename } from "./torrent.js";
import { logger } from "./logger.js";
import { resultOf, resultOfErr } from "./Result.js";
export function getFiles(meta) {
    if (!meta.info.files) {
        return [
            {
                name: meta.name,
                path: meta.name,
                length: meta.length,
            },
        ];
    }
    const unsortedFiles = meta.info.files.map((file) => {
        const rawPathSegments = file["path.utf-8"] || file.path;
        const pathSegments = rawPathSegments.map((s) => s.toString());
        return {
            name: pathSegments[pathSegments.length - 1],
            length: file.length,
            // Note that we don't use path.join here because of
            // https://github.com/cross-seed/cross-seed/issues/46.
            // path.join ignores zero-length path segments,
            // which we do not want.
            path: [meta.name, ...pathSegments].join(osSpecificPathSeparator),
        };
    });
    return sortBy(unsortedFiles, "path");
}
export function createSearcheeFromMetafile(meta) {
    return {
        files: getFiles(meta),
        infoHash: meta.infoHash,
        name: meta.name,
        length: meta.length,
    };
}
export async function createSearcheeFromTorrentFile(filepath) {
    try {
        const meta = await parseTorrentFromFilename(filepath);
        return resultOf(createSearcheeFromMetafile(meta));
    }
    catch (e) {
        logger.error(`Failed to parse ${basename(filepath)}`);
        logger.debug(e);
        return resultOfErr(e);
    }
}
//# sourceMappingURL=searchee.js.map