import { EP_REGEX, EXTENSIONS, MOVIE_REGEX, SEASON_REGEX, } from "./constants.js";
export var MediaType;
(function (MediaType) {
    MediaType["EPISODE"] = "episode";
    MediaType["SEASON"] = "pack";
    MediaType["MOVIE"] = "movie";
    MediaType["OTHER"] = "unknown";
})(MediaType = MediaType || (MediaType = {}));
export function stripExtension(filename) {
    for (const ext of EXTENSIONS) {
        const re = new RegExp(`\\.${ext}$`);
        if (re.test(filename))
            return filename.replace(re, "");
    }
    return filename;
}
export function nMsAgo(n) {
    return Date.now() - n;
}
export function wait(n) {
    return new Promise((resolve) => setTimeout(resolve, n));
}
export function getTag(name) {
    return EP_REGEX.test(name)
        ? MediaType.EPISODE
        : SEASON_REGEX.test(name)
            ? MediaType.SEASON
            : MOVIE_REGEX.test(name)
                ? MediaType.MOVIE
                : MediaType.OTHER;
}
export async function time(cb, times) {
    const before = performance.now();
    try {
        return await cb();
    }
    finally {
        times.push(performance.now() - before);
    }
}
export function cleanseSeparators(str) {
    return str
        .replace(/[._()[\]]/g, " ")
        .replace(/\s+/g, " ")
        .trim();
}
export function reformatTitleForSearching(name) {
    var _a, _b, _c;
    const seasonMatch = name.match(SEASON_REGEX);
    const movieMatch = name.match(MOVIE_REGEX);
    const episodeMatch = name.match(EP_REGEX);
    const fullMatch = (_c = (_b = (_a = episodeMatch === null || episodeMatch === void 0 ? void 0 : episodeMatch[0]) !== null && _a !== void 0 ? _a : seasonMatch === null || seasonMatch === void 0 ? void 0 : seasonMatch[0]) !== null && _b !== void 0 ? _b : movieMatch === null || movieMatch === void 0 ? void 0 : movieMatch[0]) !== null && _c !== void 0 ? _c : name;
    return cleanseSeparators(fullMatch);
}
export const tap = (fn) => (value) => {
    fn(value);
    return value;
};
export async function filterAsync(arr, predicate) {
    const results = await Promise.all(arr.map(predicate));
    return arr.filter((_, index) => results[index]);
}
export function humanReadable(timestamp) {
    // swedish conventions roughly follow the iso format!
    return new Date(timestamp).toLocaleString("sv");
}
export function formatAsList(strings) {
    // @ts-expect-error Intl.ListFormat totally exists on node 12
    return new Intl.ListFormat("en", {
        style: "long",
        type: "conjunction",
    }).format(strings);
}
//# sourceMappingURL=utils.js.map